==> gis-viewer-3.6.1-20150215.033239-22-sources.jar: org/gcube/portlets/user/gisviewer/client/GisViewerService.java <==
package org.gcube.portlets.user.gisviewer.client;


import java.util.List;

import org.gcube.portlets.user.gisviewer.client.commons.beans.DataResult;
import org.gcube.portlets.user.gisviewer.client.commons.beans.GisViewerBaseLayerInterface;
import org.gcube.portlets.user.gisviewer.client.commons.beans.LayerItem;
import org.gcube.portlets.user.gisviewer.client.commons.beans.LayerItemsResult;
import org.gcube.portlets.user.gisviewer.client.commons.beans.Property;
import org.gcube.portlets.user.gisviewer.client.commons.beans.WfsTable;
import org.gcube.portlets.user.gisviewer.client.commons.beans.WmsRequest;

import com.google.gwt.user.client.rpc.RemoteService;
import com.google.gwt.user.client.rpc.RemoteServiceRelativePath;

/**
 * The client side stub for the RPC service.
 */
@RemoteServiceRelativePath("GisViewerService")
public interface GisViewerService extends RemoteService {
	
	String getTransectUrl();

	List<DataResult> getDataResult(List<String> urls);
	
	LayerItemsResult getGroupsInfo(String groupName);
	
	LayerItemsResult getLayersInfo(List<String> layersName);
	
	LayerItemsResult getLayersInfoByLayerItems(List<LayerItem> layerItems);
	
	List<WfsTable> getDataResult(List<LayerItem> layerItems, String bbox);

	
	
	/**
	 * Added by Francesco M. 10/09/2013
	 * @param geoserverUrl
	 * @param layer
	 * @return
	 */
	List<Property> getListProperty(String geoserverUrl, LayerItem layer);

	/**
	 * @param layerItems
	 * @param bbox
	 * @param maxWFSFeature
	 * @return
	 */
	List<WfsTable> getDataResult(List<LayerItem> layerItems, String bbox, int maxWFSFeature);


//	LayerItemsResult getLayersInfoByLayerConfigurations(List<LayerConfiguration> layerConfigurations);
	
	List<? extends GisViewerBaseLayerInterface> getBaseLayersToGisViewer();
	
	String parseWmsRequest(WmsRequest request) throws Exception;

}

==> gis-viewer-3.8.0-20151117.022331-48-sources.jar: org/gcube/portlets/user/gisviewer/client/GisViewerService.java <==
package org.gcube.portlets.user.gisviewer.client;


import java.util.List;

import org.gcube.portlets.user.gisviewer.client.commons.beans.DataResult;
import org.gcube.portlets.user.gisviewer.client.commons.beans.GisViewerBaseLayerInterface;
import org.gcube.portlets.user.gisviewer.client.commons.beans.LayerItem;
import org.gcube.portlets.user.gisviewer.client.commons.beans.LayerItemsResult;
import org.gcube.portlets.user.gisviewer.client.commons.beans.Property;
import org.gcube.portlets.user.gisviewer.client.commons.beans.TransectParameters;
import org.gcube.portlets.user.gisviewer.client.commons.beans.WfsTable;
import org.gcube.portlets.user.gisviewer.client.commons.beans.WmsRequest;

import com.google.gwt.user.client.rpc.RemoteService;
import com.google.gwt.user.client.rpc.RemoteServiceRelativePath;

/**
 * The client side stub for the RPC service.
 */
@RemoteServiceRelativePath("GisViewerService")
public interface GisViewerService extends RemoteService {
	
	TransectParameters getTransectParameters();

	List<DataResult> getDataResult(List<String> urls);
	
	LayerItemsResult getGroupsInfo(String groupName);
	
	LayerItemsResult getLayersInfo(List<String> layersName);
	
	LayerItemsResult getLayersInfoByLayerItems(List<LayerItem> layerItems);
	
	List<WfsTable> getDataResult(List<LayerItem> layerItems, String bbox);

	
	
	/**
	 * Added by Francesco M. 10/09/2013
	 * @param geoserverUrl
	 * @param layer
	 * @return
	 */
	List<Property> getListProperty(String geoserverUrl, LayerItem layer);

	/**
	 * @param layerItems
	 * @param bbox
	 * @param maxWFSFeature
	 * @return
	 */
	List<WfsTable> getDataResult(List<LayerItem> layerItems, String bbox, int maxWFSFeature);


//	LayerItemsResult getLayersInfoByLayerConfigurations(List<LayerConfiguration> layerConfigurations);
	
	List<? extends GisViewerBaseLayerInterface> getBaseLayersToGisViewer();
	
	String parseWmsRequest(WmsRequest request) throws Exception;

}
